Struct polymath::PolymathError
source · pub struct PolymathError {
pub error_kind: PolymathErrorKind,
pub error: String,
}Fields
error_kind: PolymathErrorKinderror: StringImplementations
sourceimpl PolymathError
impl PolymathError
sourcepub fn new(error_kind: PolymathErrorKind, error: &str) -> Self
pub fn new(error_kind: PolymathErrorKind, error: &str) -> Self
Create a new Polymath error
sourcepub fn other(error: &str) -> Self
pub fn other(error: &str) -> Self
Same as PolymathError::new(), with the error kind auto set to: Other
Examples:
use polymath::{PolymathError, PolymathErrorKind};
fn main() {
let error1 = PolymathError::new(PolymathErrorKind::Other, "This is an error!");
let error2 = PolymathError::other("This is an error!");
assert!(error1 == error2);
}Trait Implementations
sourceimpl Clone for PolymathError
impl Clone for PolymathError
sourcefn clone(&self) -> PolymathError
fn clone(&self) -> PolymathError
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for PolymathError
impl Debug for PolymathError
sourceimpl Hash for PolymathError
impl Hash for PolymathError
sourceimpl Ord for PolymathError
impl Ord for PolymathError
sourcefn cmp(&self, other: &PolymathError) -> Ordering
fn cmp(&self, other: &PolymathError) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq for PolymathError
impl PartialEq for PolymathError
sourcefn eq(&self, other: &PolymathError) -> bool
fn eq(&self, other: &PolymathError) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for PolymathError
impl PartialOrd for PolymathError
sourcefn partial_cmp(&self, other: &PolymathError) -> Option<Ordering>
fn partial_cmp(&self, other: &PolymathError) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Eq for PolymathError
impl StructuralEq for PolymathError
impl StructuralPartialEq for PolymathError